@@ -1,5 +1,7 @@
 #! /usr/bin/env perl
 
+use lib "../lib";
+
 use strict;
 use 5.012;
 use App::CPRReporter;
@@ -26,20 +28,22 @@ my $reporter = App::CPRReporter->new(
 );
 $reporter->run();
 
-# PODNAME: cpr_reporter.pl
+# PODNAME: cpr_report.pl
 # ABSTRACT: Generate an overview of the status of people enrolled for CPR training.
 
 __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-cpr_reporter.pl - Generate an overview of the status of people enrolled for CPR training.
+cpr_report.pl - Generate an overview of the status of people enrolled for CPR training.
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
